scxpand.util.classes
====================

.. automodule:: scxpand.util.classes

   
   .. rubric:: Functions

   .. autosummary::
   
      ensure_model_type
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseParams
      DataAugmentParams
      DataLoaderParams
      LRSchedulerParams
      LRSchedulerType
      ModelType
      OptimizerParams
      OptimizerType
      SamplerType
   